package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubUpdateDto;
import com.caimei365.user.service.ClubService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.Map;


/**
 * 机构用户API
 *
 * @author : Charles
 * @date : 2021/3/4
 */
@Api(tags="机构用户API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/club")
public class ClubApi {

    private final ClubService clubService;

    /**
     * 根据用户Id查询机构资料
     *
     * spi旧接口：/user/club/applicationData
     *
     * @param userId 用户Id
     *
     * @return Map(userPo,clubPo)
     */
    @ApiOperation("查询机构资料")
    @ApiImplicitParam(required = true, name = "userId", value = "用户Id")
    @GetMapping("/info")
    public ResponseJson<Map<String, Object>> getClubUserInfo(Integer userId) {
        return clubService.getClubUserInfo(userId);
    }

    /**
     * 修改机构资料
     *
     * spi旧接口：/operation/modifiedData
	 *
	 * @param club ClubUpdateDto:{
	 *                      clubId                 机构ID
	 *                      userId                 用户ID
	 *                      name                   机构名称
	 *                      shortName                  机构简称(shortName)
	 *                      contractEmail          邮箱（contractEmail1）
	 *                      contractPhone          固定电话
	 *                      linkMan                联系人（linkMan1）
	 *                      provinceId             省Id
	 *                      cityId                 市Id
	 *                      townId                 县区Id
	 *                      address                地址
	 *                      shopPhoto              门头照(headpic)
	 *                      businessLicense        营业执照（businessLicenseImage）
	 *                      socialCreditCode       统一社会信用代码（socialCreditCode）
	 *                      firstClubType          一级分类：医美=1和生美=2
	 *                      secondClubType         医美的二级分类：诊所=1、门诊=2、医院=3。  生美没有二级分类
	 *                      department             医美分类下的门诊和医院则需要填写科室
	 *                      medicalPracticeLicense 医美分类必须上传医疗执业许可证（medicalPracticeLicenseImg）
	 *                      mainProduct            主打项目（mainpro）
	 *                      fax                    传真
	 *                      profile                公司简介
	 *                  }
	 * @return ClubUpdateDto
     */
	@ApiOperation("更新机构资料")
    @PostMapping("/info/update")
    public ResponseJson<ClubUpdateDto> updateClubUserInfo(ClubUpdateDto club) {
		return clubService.updateClubUserInfo(club);
    }


}
